/****************************************************************************
 *
 *   Copyright (C) 2016 PX4 Development Team. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name PX4 nor the names of its contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
/**
 * @file pipe_protocol.cpp
 *
 * @author Julian Oes <julian@oes.ch>
 * @author Beat Küng <beat-kueng@gmx.net>
 */

#include <stdint.h>
#include <stdio.h>
#include <inttypes.h>

#include "pipe_protocol.h"

static const char CLIENT_SEND_PIPE_PATH[] = "/tmp/px4_client_send_pipe-";
static const char CLIENT_RECV_PIPE_PATH[] = "/tmp/px4_client_recv_pipe";


namespace px4_daemon
{


unsigned get_client_send_packet_length(const client_send_packet_s *packet)
{
	return sizeof(client_send_packet_s) - sizeof(packet->payload) + packet->header.payload_length;
}

unsigned get_client_recv_packet_length(const client_recv_packet_s *packet)
{
	return sizeof(client_recv_packet_s) - sizeof(packet->payload) + packet->header.payload_length;
}

int get_client_recv_pipe_path(const uint64_t uuid, char *path, const size_t path_len)
{
	return snprintf(path, path_len, "%s-%016" PRIx64, CLIENT_RECV_PIPE_PATH, uuid);
}

std::string get_client_send_pipe_path(int instance_id)
{
	return std::string(CLIENT_SEND_PIPE_PATH) + std::to_string(instance_id);
}

} // namespace px4_daemon

